===============
 |MyGNUHealth|
===============

.. Note:: This document is licensed under Creative Commons 
    Attribution-ShareAlike 4.0 International (CC BY-SA 4.0) 

.. contents::

MyGNUHealth is a Libre Personal Health Record that is part of the GNU Health
ecosystem. This application can be run both in desktop and mobile devices.

The GNU Health Personal Health Record 
=====================================


Introduction
============
MyGNUHealth is a desktop and mobile application that helps you to take 
control of your health. As a Personal Health Record, you will be able to assess, 
record and take action upon the determinants of the main health spheres 
(bio-psycho-social).

MyGNUHealth will be your health companion, and it will allow to connect you
with your health professionals, to proactively be on top of your health.
MyGNUHealth puts you in the driver's seat, an active member of the system of
health.


The need of a Libre PHR
=======================
A Personal Health Record must respect the freedom of the individual.
We need to make sure that we are in charge of our health, and that the information
we store is private.

There are be different Health record applications in the market, but one of
the key benefits of MyGNUHealth is that is Libre. By Libre we mean that the source
code of the application is available; the user can modify it if she wishes, and
interact with the community to improve the application. 

MyGNUHealth is part of the GNU Health ecosystem, a social project that uses
technology to deliver Social Medicine, equity, freedom and privacy in healthcare.

MyGNUHealth is licensed under the GNU General Public License v3. It is Libre, and
it will remain Libre.

Downloading the application
===========================

MyGNUHealth will be available from different sources. The easiest way is to
check your current operating system or distribution.

Using MyGNUHealth
=================

Starting up the application
---------------------------
|InitialScreen|

Click or tap into the MyGNUHealth icon on your mobile device or desktop.
You will be presented with the welcoming screen.


Profile initialization
----------------------
The very firt time MyGNUHealth is run, you need to enter very basic information
about yourself. The date of birth, height and sex are the main parameters to be included. They are used in medical contexts, so is important that you fill them in.
In this step, you will also set up your personal key.
|ProfileInitialization|



Signing in to MyGNUHealth
-------------------------
|LoginScreen|

The first time you use the application, the initial key is *mygh*
(no quotes).


.. Note:: For security reasons, you're strongly adviced to change the personal
    key once you log in. You can change your key in the **profile setttings**


The main screen
---------------
|MainScreen|

Once you sign in, you are presented to the MyGNUHealth main screen, with the 
main components:

* **Health Tracker**: This section records quantifiable events,
    from the biological, lifestyle and psychological domains.
     
* **Book of Life**: The book of life is your personal health diary, made of 
    *Pages of Life*. From the genetic and molecular components to the social 
    events throughout your life that make you a unique individual.

.. note:: The main screen components and layout might change from one release
    to another.


.. |InitialScreen| image:: ./images/initial_screen.png
.. |MainScreen| image:: ./images/main_screen.png
.. |ProfileInitialization| image:: ./images/user_profile_initialization.png
.. |MyGNUHealth| image:: ./images/mygnuhealth.png
.. |LoginScreen| image:: ./images/login_screen.png
